@@ -4,28 +4,16 @@ from Crypto.Random import get_random_bytes
 import os
 import base64
 
-
-def check_key_path(key_path: str):
-    if not os.path.exists(key_path) or not os.path.isfile(key_path):
-        raise Exception(f'Key does not exist at {key_path}')
-
-
-def encrypt(key_path: str, content: str):
-    check_key_path(key_path)
-    key = RSA.import_key(open(key_path, 'r').read())
+def encrypt(key: str, content: str):
     return base64.b64encode(PKCS1_OAEP.new(key).encrypt(content.encode('utf-8'))).decode('utf-8')
 
 
-def decrypt(key_path: str, content: str):
-    check_key_path(key_path)
-    pkey = RSA.import_key(open(key_path, 'r').read())
+def decrypt(key: str, content: str):
     return PKCS1_OAEP.new(pkey).decrypt(base64.b64decode(content.encode('utf-8'))).decode('utf-8')
 
 
-def big_encrypt(key_path: str, content: str) -> (str, str):
-    check_key_path(key_path)
+def big_encrypt(key: str, content: str) -> (str, str):
     aes_key = get_random_bytes(16)
-    rsa_key = RSA.import_key(open(key_path, 'r').read())
 
     # Encrypt the data
     cipher = AES.new(aes_key, AES.MODE_EAX)
@@ -39,9 +27,7 @@ def big_encrypt(key_path: str, content: str) -> (str, str):
     return ciphertext, f'{enc_key},{base64.b64encode(cipher.nonce).decode("utf-8")}'
 
 
-def big_decrypt(key_path: str, aes_string: str, content: str):
-    check_key_path(key_path)
-    rsa_key = RSA.import_key(open(key_path, 'r').read())
+def big_decrypt(key: str, aes_string: str, content: str):
     enc_key, nonce = aes_string.split(',')
 
     # Decrypt the aes key
